==> pika-0.18.0_0%2Bjemalloc%2Bmpich.darwin_22.arm64.tbz2: opt/local/lib/cmake/pika/pika_cache_variables.cmake <==
# Copyright (c) 2019 Ste||ar Group
#
# SPDX-License-Identifier: BSL-1.0
# Distributed under the Boost Software License, Version 1.0. (See accompanying
# file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)

# File to store the PIKA_* cache variables

set(PIKA_ENABLED_MODULES affinity;allocator_support;assertion;async_base;async_combinators;async;async_mpi;command_line_handling;concepts;concurrency;config;coroutines;datastructures;debugging;errors;execution;execution_base;executors;filesystem;functional;futures;hashing;include;ini;init_runtime;iterator_support;itt_notify;lcos;lock_registration;logging;memory;mpi_base;pack_traversal;prefix;preprocessor;program_options;properties;resource_partitioner;runtime_configuration;runtime;schedulers;string_util;synchronization;tag_invoke;thread_pool_util;thread_pools;thread_support;threading;threading_base;thread_manager;timing;topology;type_support;util;version)
set(PIKA_EXPORT_INTERNAL_TARGETS pika_private_flags;pika_public_flags;pika_affinity;pika_allocator_support;pika_assertion;pika_async_base;pika_async_combinators;pika_async;pika_async_mpi;pika_command_line_handling;pika_concepts;pika_concurrency;pika_config;pika_coroutines;pika_datastructures;pika_debugging;pika_errors;pika_execution;pika_execution_base;pika_executors;pika_filesystem;pika_functional;pika_futures;pika_hashing;pika_include;pika_ini;pika_init_runtime;pika_iterator_support;pika_itt_notify;pika_lcos;pika_lock_registration;pika_logging;pika_memory;pika_mpi_base;pika_pack_traversal;pika_prefix;pika_preprocessor;pika_program_options;pika_properties;pika_resource_partitioner;pika_runtime_configuration;pika_runtime;pika_schedulers;pika_string_util;pika_synchronization;pika_tag_invoke;pika_thread_pool_util;pika_thread_pools;pika_thread_support;pika_threading;pika_threading_base;pika_thread_manager;pika_timing;pika_topology;pika_type_support;pika_util;pika_version;pika_base_libraries)
set(PIKA_EXPORT_TARGETS pika)
set(PIKA_PLATFORM native)
set(PIKA_WITH_ADDITIONAL_HWLOC_TESTING OFF)
set(PIKA_WITH_APEX OFF)
set(PIKA_WITH_BINARY_DIR /opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_devel_pika/pika/work/build)
set(PIKA_WITH_BOOST_CONTEXT ON)
set(PIKA_WITH_BOOST_ITERATOR_TRAVERSAL_TAG_COMPATIBILITY OFF)
set(PIKA_WITH_BUILD_BINARY_PACKAGE OFF)
set(PIKA_WITH_C11_ALIGNED_ALLOC FALSE)
set(PIKA_WITH_C11_ALIGNED_ALLOC_RESULT FALSE)
set(PIKA_WITH_CHECK_MODULE_DEPENDENCIES OFF)
set(PIKA_WITH_COMPILER_WARNINGS ON)
set(PIKA_WITH_COMPILER_WARNINGS_AS_ERRORS OFF)
set(PIKA_WITH_COROUTINE_COUNTERS OFF)
set(PIKA_WITH_CUDA OFF)
set(PIKA_WITH_CXX11_ATOMIC TRUE)
set(PIKA_WITH_CXX11_ATOMIC_128BIT TRUE)
set(PIKA_WITH_CXX11_ATOMIC_128BIT_RESULT TRUE)
set(PIKA_WITH_CXX11_ATOMIC_RESULT TRUE)
set(PIKA_WITH_CXX11_SHARED_PTR_LWG3018 TRUE)
set(PIKA_WITH_CXX11_SHARED_PTR_LWG3018_RESULT TRUE)
set(PIKA_WITH_CXX11_STD_QUICK_EXIT FALSE)
set(PIKA_WITH_CXX11_STD_QUICK_EXIT_RESULT FALSE)
set(PIKA_WITH_CXX17_ALIGNED_NEW TRUE)
set(PIKA_WITH_CXX17_ALIGNED_NEW_RESULT TRUE)
set(PIKA_WITH_CXX17_COPY_ELISION TRUE)
set(PIKA_WITH_CXX17_COPY_ELISION_RESULT TRUE)
set(PIKA_WITH_CXX17_MEMORY_RESOURCE FALSE)
set(PIKA_WITH_CXX17_MEMORY_RESOURCE_RESULT FALSE)
set(PIKA_WITH_CXX17_STD_ALIGNED_ALLOC FALSE)
set(PIKA_WITH_CXX17_STD_ALIGNED_ALLOC_RESULT FALSE)
set(PIKA_WITH_CXX17_STD_EXECUTION_POLICIES FALSE)
set(PIKA_WITH_CXX17_STD_EXECUTION_POLICIES_RESULT FALSE)
set(PIKA_WITH_CXX20_TRIVIAL_VIRTUAL_DESTRUCTOR FALSE)
set(PIKA_WITH_CXX20_TRIVIAL_VIRTUAL_DESTRUCTOR_RESULT FALSE)
set(PIKA_WITH_CXX_FLAG_FDIAGNOSTICS_SHOW_OPTION 1)
set(PIKA_WITH_CXX_FLAG_FTEMPLATE_DEPTH_256 1)
set(PIKA_WITH_CXX_FLAG_PTHREAD 1)
set(PIKA_WITH_CXX_FLAG_WALL 1)
set(PIKA_WITH_CXX_FLAG_WCAST_ALIGN 1)
set(PIKA_WITH_CXX_FLAG_WCAST_QUAL 1)
set(PIKA_WITH_CXX_FLAG_WDOUBLE_PROMOTION 1)
set(PIKA_WITH_CXX_FLAG_WERROR_FORMAT 1)
set(PIKA_WITH_CXX_FLAG_WERROR_MISSING_BRACES 1)
set(PIKA_WITH_CXX_FLAG_WERROR_PARENTHESES 1)
set(PIKA_WITH_CXX_FLAG_WERROR_REORDER 1)
set(PIKA_WITH_CXX_FLAG_WERROR_RETURN_TYPE 1)
set(PIKA_WITH_CXX_FLAG_WERROR_SEQUENCE_POINT 1)
set(PIKA_WITH_CXX_FLAG_WERROR_SIGN_COMPARE 1)
set(PIKA_WITH_CXX_FLAG_WERROR_UNINITIALIZED 1)
set(PIKA_WITH_CXX_FLAG_WERROR_VLA 1)
set(PIKA_WITH_CXX_FLAG_WEXTRA 1)
set(PIKA_WITH_CXX_FLAG_WFORMAT_2 1)
set(PIKA_WITH_CXX_FLAG_WINIT_SELF 1)
set(PIKA_WITH_CXX_FLAG_WNO_ATTRIBUTES 1)
set(PIKA_WITH_CXX_FLAG_WNO_CAST_ALIGN 1)
set(PIKA_WITH_CXX_FLAG_WNO_FORMAT_NONLITERAL 1)
set(PIKA_WITH_CXX_FLAG_WNO_NOEXCEPT_TYPE 1)
set(PIKA_WITH_CXX_FLAG_WNO_SIGN_PROMO 1)
set(PIKA_WITH_CXX_FLAG_WNO_STRICT_ALIASING 1)
set(PIKA_WITH_CXX_FLAG_WNO_SYNC_NAND )
set(PIKA_WITH_CXX_FLAG_WPEDANTIC 1)
set(PIKA_WITH_CXX_LAMBDA_CAPTURE_DECLTYPE TRUE)
set(PIKA_WITH_CXX_LAMBDA_CAPTURE_DECLTYPE_RESULT TRUE)
set(PIKA_WITH_CXX_STANDARD 17)
set(PIKA_WITH_DEPRECATION_WARNINGS OFF)
set(PIKA_WITH_DISABLED_SIGNAL_EXCEPTION_HANDLERS OFF)
set(PIKA_WITH_EXAMPLES OFF)
set(PIKA_WITH_EXECUTABLE_PREFIX )
set(PIKA_WITH_FULL_RPATH OFF)
set(PIKA_WITH_GCC_VERSION_CHECK ON)
set(PIKA_WITH_GPU_SUPPORT OFF)
set(PIKA_WITH_HIDDEN_VISIBILITY OFF)
set(PIKA_WITH_HIP OFF)
set(PIKA_WITH_ITTNOTIFY OFF)
set(PIKA_WITH_JEMALLOC_PREFIX <none>)
set(PIKA_WITH_LOGGING ON)
set(PIKA_WITH_MALLOC jemalloc)
set(PIKA_WITH_MAX_CPU_COUNT )
set(PIKA_WITH_MAX_NUMA_DOMAIN_COUNT 8)
set(PIKA_WITH_MPI ON)
set(PIKA_WITH_MPI_ENV MV2_COMM_WORLD_RANK;PMI_RANK;OMPI_COMM_WORLD_SIZE;ALPS_APP_PE;PMIX_RANK;PALS_NODEID)
set(PIKA_WITH_MPI_MULTITHREADED ON)
set(PIKA_WITH_NICE_THREADLEVEL OFF)
set(PIKA_WITH_PARALLEL_TESTS_BIND_NONE OFF)
set(PIKA_WITH_PRECOMPILED_HEADERS OFF)
set(PIKA_WITH_PSEUDO_DEPENDENCIES ON)
set(PIKA_WITH_RPM OFF)
set(PIKA_WITH_SANITIZERS OFF)
set(PIKA_WITH_SCHEDULER_LOCAL_STORAGE OFF)
set(PIKA_WITH_SPINLOCK_DEADLOCK_DETECTION OFF)
set(PIKA_WITH_SPINLOCK_POOL_NUM 128)
set(PIKA_WITH_STACKTRACES ON)
set(PIKA_WITH_STDEXEC OFF)
set(PIKA_WITH_SWAP_CONTEXT_EMULATION OFF)
set(PIKA_WITH_TARGET_ARCHITECTURE arm64)
set(PIKA_WITH_TESTS OFF)
set(PIKA_WITH_TESTS_DEBUG_LOG OFF)
set(PIKA_WITH_TESTS_DEBUG_LOG_DESTINATION cout)
set(PIKA_WITH_TESTS_MAX_THREADS 0)
set(PIKA_WITH_THREAD_BACKTRACE_DEPTH 20)
set(PIKA_WITH_THREAD_BACKTRACE_ON_SUSPENSION OFF)
set(PIKA_WITH_THREAD_CREATION_AND_CLEANUP_RATES OFF)
set(PIKA_WITH_THREAD_CUMULATIVE_COUNTS OFF)
set(PIKA_WITH_THREAD_DEBUG_INFO OFF)
set(PIKA_WITH_THREAD_DESCRIPTION_FULL OFF)
set(PIKA_WITH_THREAD_GUARD_PAGE ON)
set(PIKA_WITH_THREAD_IDLE_RATES OFF)
set(PIKA_WITH_THREAD_LOCAL_STORAGE ON)
set(PIKA_WITH_THREAD_MANAGER_IDLE_BACKOFF ON)
set(PIKA_WITH_THREAD_QUEUE_WAITTIME OFF)
set(PIKA_WITH_THREAD_STACK_MMAP ON)
set(PIKA_WITH_THREAD_STEALING_COUNTS OFF)
set(PIKA_WITH_THREAD_TARGET_ADDRESS OFF)
set(PIKA_WITH_TOOLS OFF)
set(PIKA_WITH_TRACY OFF)
set(PIKA_WITH_UNISTD_H TRUE)
set(PIKA_WITH_UNISTD_H_RESULT TRUE)
set(PIKA_WITH_UNITY_BUILD ON)
set(PIKA_WITH_VALGRIND OFF)
set(PIKA_WITH_VERIFY_LOCKS OFF)
set(PIKA_WITH_VERIFY_LOCKS_BACKTRACE OFF)
set(PIKA_WITH_VIM_YCM OFF)

==> pika-0.25.0_0%2Bjemalloc%2Bmpich.darwin_22.arm64.tbz2: opt/local/lib/cmake/pika/pika_cache_variables.cmake <==
# Copyright (c) 2019 Ste||ar Group
#
# SPDX-License-Identifier: BSL-1.0
# Distributed under the Boost Software License, Version 1.0. (See accompanying
# file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)

# File to store the PIKA_* cache variables

set(PIKA_ENABLED_MODULES affinity;allocator_support;assertion;async_base;async_mpi;command_line_handling;concepts;concurrency;config;coroutines;datastructures;debugging;errors;execution;execution_base;executors;filesystem;functional;hashing;include;ini;init_runtime;iterator_support;itt_notify;lock_registration;logging;memory;mpi_base;prefix;preprocessor;program_options;properties;resource_partitioner;runtime_configuration;runtime;schedulers;string_util;synchronization;tag_invoke;thread_pools;thread_support;threading;threading_base;thread_manager;timing;topology;type_support;util;version)
set(PIKA_EXPORT_INTERNAL_TARGETS pika_private_flags;pika_public_flags;pika_affinity;pika_allocator_support;pika_assertion;pika_async_base;pika_async_mpi;pika_command_line_handling;pika_concepts;pika_concurrency;pika_config;pika_coroutines;pika_datastructures;pika_debugging;pika_errors;pika_execution;pika_execution_base;pika_executors;pika_filesystem;pika_functional;pika_hashing;pika_include;pika_ini;pika_init_runtime;pika_iterator_support;pika_itt_notify;pika_lock_registration;pika_logging;pika_memory;pika_mpi_base;pika_prefix;pika_preprocessor;pika_program_options;pika_properties;pika_resource_partitioner;pika_runtime_configuration;pika_runtime;pika_schedulers;pika_string_util;pika_synchronization;pika_tag_invoke;pika_thread_pools;pika_thread_support;pika_threading;pika_threading_base;pika_thread_manager;pika_timing;pika_topology;pika_type_support;pika_util;pika_version;pika_base_libraries)
set(PIKA_EXPORT_TARGETS pika)
set(PIKA_PLATFORM native)
set(PIKA_WITH_ADDITIONAL_HWLOC_TESTING OFF)
set(PIKA_WITH_APEX OFF)
set(PIKA_WITH_BINARY_DIR /opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_devel_pika/pika/work/build)
set(PIKA_WITH_BOOST_CONTEXT ON)
set(PIKA_WITH_BOOST_ITERATOR_TRAVERSAL_TAG_COMPATIBILITY OFF)
set(PIKA_WITH_BUILD_BINARY_PACKAGE OFF)
set(PIKA_WITH_C11_ALIGNED_ALLOC FALSE)
set(PIKA_WITH_C11_ALIGNED_ALLOC_RESULT FALSE)
set(PIKA_WITH_CHECK_MODULE_DEPENDENCIES OFF)
set(PIKA_WITH_COMPILER_WARNINGS ON)
set(PIKA_WITH_COMPILER_WARNINGS_AS_ERRORS OFF)
set(PIKA_WITH_COROUTINE_COUNTERS OFF)
set(PIKA_WITH_CUDA OFF)
set(PIKA_WITH_CXX11_ATOMIC TRUE)
set(PIKA_WITH_CXX11_ATOMIC_128BIT TRUE)
set(PIKA_WITH_CXX11_ATOMIC_128BIT_RESULT TRUE)
set(PIKA_WITH_CXX11_ATOMIC_RESULT TRUE)
set(PIKA_WITH_CXX11_SHARED_PTR_LWG3018 TRUE)
set(PIKA_WITH_CXX11_SHARED_PTR_LWG3018_RESULT TRUE)
set(PIKA_WITH_CXX11_STD_QUICK_EXIT FALSE)
set(PIKA_WITH_CXX11_STD_QUICK_EXIT_RESULT FALSE)
set(PIKA_WITH_CXX17_ALIGNED_NEW TRUE)
set(PIKA_WITH_CXX17_ALIGNED_NEW_RESULT TRUE)
set(PIKA_WITH_CXX17_COPY_ELISION TRUE)
set(PIKA_WITH_CXX17_COPY_ELISION_RESULT TRUE)
set(PIKA_WITH_CXX17_MEMORY_RESOURCE FALSE)
set(PIKA_WITH_CXX17_MEMORY_RESOURCE_RESULT FALSE)
set(PIKA_WITH_CXX17_STD_ALIGNED_ALLOC FALSE)
set(PIKA_WITH_CXX17_STD_ALIGNED_ALLOC_RESULT FALSE)
set(PIKA_WITH_CXX20_TRIVIAL_VIRTUAL_DESTRUCTOR FALSE)
set(PIKA_WITH_CXX20_TRIVIAL_VIRTUAL_DESTRUCTOR_RESULT FALSE)
set(PIKA_WITH_CXX23_STATIC_CALL_OPERATOR FALSE)
set(PIKA_WITH_CXX23_STATIC_CALL_OPERATOR_RESULT FALSE)
set(PIKA_WITH_CXX_FLAG_FDIAGNOSTICS_SHOW_OPTION 1)
set(PIKA_WITH_CXX_FLAG_FTEMPLATE_DEPTH_256 1)
set(PIKA_WITH_CXX_FLAG_PTHREAD 1)
set(PIKA_WITH_CXX_FLAG_WALL 1)
set(PIKA_WITH_CXX_FLAG_WCAST_ALIGN 1)
set(PIKA_WITH_CXX_FLAG_WCAST_QUAL 1)
set(PIKA_WITH_CXX_FLAG_WDOUBLE_PROMOTION 1)
set(PIKA_WITH_CXX_FLAG_WERROR_FORMAT 1)
set(PIKA_WITH_CXX_FLAG_WERROR_MISSING_BRACES 1)
set(PIKA_WITH_CXX_FLAG_WERROR_PARENTHESES 1)
set(PIKA_WITH_CXX_FLAG_WERROR_REORDER 1)
set(PIKA_WITH_CXX_FLAG_WERROR_RETURN_TYPE 1)
set(PIKA_WITH_CXX_FLAG_WERROR_SEQUENCE_POINT 1)
set(PIKA_WITH_CXX_FLAG_WERROR_SIGN_COMPARE 1)
set(PIKA_WITH_CXX_FLAG_WERROR_UNINITIALIZED 1)
set(PIKA_WITH_CXX_FLAG_WERROR_VLA 1)
set(PIKA_WITH_CXX_FLAG_WEXTRA 1)
set(PIKA_WITH_CXX_FLAG_WFORMAT_2 1)
set(PIKA_WITH_CXX_FLAG_WINIT_SELF 1)
set(PIKA_WITH_CXX_FLAG_WNO_ATTRIBUTES 1)
set(PIKA_WITH_CXX_FLAG_WNO_CAST_ALIGN 1)
set(PIKA_WITH_CXX_FLAG_WNO_FORMAT_NONLITERAL 1)
set(PIKA_WITH_CXX_FLAG_WNO_NOEXCEPT_TYPE 1)
set(PIKA_WITH_CXX_FLAG_WNO_SIGN_PROMO 1)
set(PIKA_WITH_CXX_FLAG_WNO_STRICT_ALIASING 1)
set(PIKA_WITH_CXX_FLAG_WNO_SYNC_NAND )
set(PIKA_WITH_CXX_FLAG_WPEDANTIC 1)
set(PIKA_WITH_CXX_LAMBDA_CAPTURE_DECLTYPE TRUE)
set(PIKA_WITH_CXX_LAMBDA_CAPTURE_DECLTYPE_RESULT TRUE)
set(PIKA_WITH_CXX_STANDARD 17)
set(PIKA_WITH_DEPRECATION_WARNINGS OFF)
set(PIKA_WITH_DISABLED_SIGNAL_EXCEPTION_HANDLERS OFF)
set(PIKA_WITH_EXAMPLES OFF)
set(PIKA_WITH_EXECUTABLE_PREFIX )
set(PIKA_WITH_FULL_RPATH OFF)
set(PIKA_WITH_GCC_VERSION_CHECK ON)
set(PIKA_WITH_GPU_SUPPORT OFF)
set(PIKA_WITH_HIDDEN_VISIBILITY OFF)
set(PIKA_WITH_HIP OFF)
set(PIKA_WITH_ITTNOTIFY OFF)
set(PIKA_WITH_JEMALLOC_PREFIX <none>)
set(PIKA_WITH_LOGGING ON)
set(PIKA_WITH_MALLOC jemalloc)
set(PIKA_WITH_MAX_CPU_COUNT )
set(PIKA_WITH_MAX_NUMA_DOMAIN_COUNT 8)
set(PIKA_WITH_MPI ON)
set(PIKA_WITH_MPI_ENV MV2_COMM_WORLD_RANK;PMI_RANK;OMPI_COMM_WORLD_SIZE;ALPS_APP_PE;PMIX_RANK;PALS_NODEID)
set(PIKA_WITH_MPI_MULTITHREADED ON)
set(PIKA_WITH_NICE_THREADLEVEL OFF)
set(PIKA_WITH_PARALLEL_TESTS_BIND_NONE OFF)
set(PIKA_WITH_PRECOMPILED_HEADERS OFF)
set(PIKA_WITH_PSEUDO_DEPENDENCIES ON)
set(PIKA_WITH_RPM OFF)
set(PIKA_WITH_SANITIZERS OFF)
set(PIKA_WITH_SCHEDULER_LOCAL_STORAGE OFF)
set(PIKA_WITH_SPINLOCK_DEADLOCK_DETECTION OFF)
set(PIKA_WITH_SPINLOCK_POOL_NUM 128)
set(PIKA_WITH_STACKTRACES ON)
set(PIKA_WITH_STDEXEC OFF)
set(PIKA_WITH_STDEXEC_SENDER_RECEIVER_CONCEPTS FALSE)
set(PIKA_WITH_STDEXEC_SENDER_RECEIVER_CONCEPTS_RESULT FALSE)
set(PIKA_WITH_SWAP_CONTEXT_EMULATION OFF)
set(PIKA_WITH_TARGET_ARCHITECTURE arm64)
set(PIKA_WITH_TESTS OFF)
set(PIKA_WITH_TESTS_DEBUG_LOG OFF)
set(PIKA_WITH_TESTS_DEBUG_LOG_DESTINATION cout)
set(PIKA_WITH_TESTS_MAX_THREADS 0)
set(PIKA_WITH_TESTS_VALGRIND OFF)
set(PIKA_WITH_TESTS_VALGRIND_OPTIONS --error-exitcode=1)
set(PIKA_WITH_THREAD_BACKTRACE_DEPTH 20)
set(PIKA_WITH_THREAD_BACKTRACE_ON_SUSPENSION OFF)
set(PIKA_WITH_THREAD_CREATION_AND_CLEANUP_RATES OFF)
set(PIKA_WITH_THREAD_CUMULATIVE_COUNTS OFF)
set(PIKA_WITH_THREAD_DEBUG_INFO OFF)
set(PIKA_WITH_THREAD_DESCRIPTION_FULL OFF)
set(PIKA_WITH_THREAD_IDLE_RATES OFF)
set(PIKA_WITH_THREAD_LOCAL_STORAGE ON)
set(PIKA_WITH_THREAD_MANAGER_IDLE_BACKOFF ON)
set(PIKA_WITH_THREAD_QUEUE_WAITTIME OFF)
set(PIKA_WITH_THREAD_STACK_MMAP ON)
set(PIKA_WITH_THREAD_STEALING_COUNTS OFF)
set(PIKA_WITH_THREAD_TARGET_ADDRESS OFF)
set(PIKA_WITH_TOOLS OFF)
set(PIKA_WITH_TRACY OFF)
set(PIKA_WITH_UNISTD_H TRUE)
set(PIKA_WITH_UNISTD_H_RESULT TRUE)
set(PIKA_WITH_UNITY_BUILD ON)
set(PIKA_WITH_VALGRIND OFF)
set(PIKA_WITH_VERIFY_LOCKS OFF)
set(PIKA_WITH_VERIFY_LOCKS_BACKTRACE OFF)
set(PIKA_WITH_VIM_YCM OFF)
